pub enum Particle {
Show 114 variants
AngryVillager,
Block(BlockState),
BlockMarker(BlockState),
Bubble,
Cloud,
Crit,
DamageIndicator,
DragonBreath,
DrippingLava,
FallingLava,
LandingLava,
DrippingWater,
FallingWater,
Dust {
color: i32,
scale: f32,
},
DustColorTransition {
from_color: i32,
to_color: i32,
scale: f32,
},
Effect,
ElderGuardian,
EnchantedHit,
Enchant,
EndRod,
EntityEffect {
color: i32,
},
ExplosionEmitter,
Explosion,
Gust,
SmallGust,
GustEmitterLarge,
GustEmitterSmall,
SonicBoom,
FallingDust(BlockState),
Firework,
Fishing,
Flame,
Infested,
CherryLeaves,
PaleOakLeaves,
TintedLeaves {
color: i32,
},
SculkSoul,
SculkCharge {
roll: f32,
},
SculkChargePop,
SoulFireFlame,
Soul,
Flash,
HappyVillager,
Composter,
Heart,
InstantEffect,
Item(Box<ItemStack>),
Vibration {
source: VibrationSourceType,
ticks: VarInt,
},
Trail {
position: DVec3,
color: i32,
duration: VarInt,
},
ItemSlime,
ItemCobweb,
ItemSnowball,
LargeSmoke,
Lava,
Mycelium,
Note,
Poof,
Portal,
Rain,
Smoke,
WhiteSmoke,
Sneeze,
Spit,
SquidInk,
SweepAttack,
TotemOfUndying,
Underwater,
Splash,
Witch,
BubblePop,
CurrentDown,
BubbleColumnUp,
Nautilus,
Dolphin,
CampfireCosySmoke,
CampfireSignalSmoke,
DrippingHoney,
FallingHoney,
LandingHoney,
FallingNectar,
FallingSporeBlossom,
Ash,
CrimsonSpore,
WarpedSpore,
SporeBlossomAir,
DrippingObsidianTear,
FallingObsidianTear,
LandingObsidianTear,
ReversePortal,
WhiteAsh,
SmallFlame,
Snowflake,
DrippingDripstoneLava,
FallingDripstoneLava,
DrippingDripstoneWater,
FallingDripstoneWater,
GlowSquidInk,
Glow,
WaxOn,
WaxOff,
ElectricSpark,
Scrape,
Shriek {
delay: VarInt,
},
EggCrack,
DustPlume,
TrialSpawnerDetection,
TrialSpawnerDetectionOminous,
VaultConnection,
DustPillar(BlockState),
OminousSpawning,
RaidOmen,
TrialOmen,
BlockCrumble(BlockState),
Firefly,
}Variants
AngryVillager
Block(BlockState)
BlockMarker(BlockState)
Bubble
Cloud
Crit
DamageIndicator
DragonBreath
DrippingLava
FallingLava
LandingLava
DrippingWater
FallingWater
Dust
DustColorTransition
Fields
Effect
ElderGuardian
EnchantedHit
Enchant
EndRod
EntityEffect
ExplosionEmitter
Explosion
Gust
SmallGust
GustEmitterLarge
GustEmitterSmall
SonicBoom
FallingDust(BlockState)
Firework
Fishing
Flame
Infested
CherryLeaves
PaleOakLeaves
TintedLeaves
SculkSoul
SculkCharge
SculkChargePop
SoulFireFlame
Soul
Flash
HappyVillager
Composter
Heart
InstantEffect
Item(Box<ItemStack>)
If the item is air or its count is 0, the client might crash.
Vibration
Fields

source: VibrationSourceTypeThe type of the vibration source defined by the
minecraft:position_source_type builtin registry.
Trail
Fields
ItemSlime
ItemCobweb
ItemSnowball
LargeSmoke
Lava
Mycelium
Note
Poof
Portal
Rain
Smoke
WhiteSmoke
Sneeze
Spit
SquidInk
SweepAttack
TotemOfUndying
Underwater
Splash
Witch
BubblePop
CurrentDown
BubbleColumnUp
Nautilus
Dolphin
CampfireCosySmoke
CampfireSignalSmoke
DrippingHoney
FallingHoney
LandingHoney
FallingNectar
FallingSporeBlossom
Ash
CrimsonSpore
WarpedSpore
SporeBlossomAir
DrippingObsidianTear
FallingObsidianTear
LandingObsidianTear
ReversePortal
WhiteAsh
SmallFlame
Snowflake
DrippingDripstoneLava
FallingDripstoneLava
DrippingDripstoneWater
FallingDripstoneWater
GlowSquidInk
Glow
WaxOn
WaxOff
ElectricSpark
Scrape
Shriek
EggCrack
DustPlume
TrialSpawnerDetection
TrialSpawnerDetectionOminous
VaultConnection
DustPillar(BlockState)
OminousSpawning
RaidOmen
TrialOmen
BlockCrumble(BlockState)
Firefly
Implementations